// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// DO NOT EDIT

#include "manual.h"
#include <stdio.h>

#define PRINT_CONSTANT(CONSTANT_NAME) \
    printf("%s;", #CONSTANT_NAME); \
    printf(_Generic((CONSTANT_NAME), \
                    char *: "%s", \
                    const char *: "%s", \
                    char: "%c", \
                    signed char: "%hhd", \
                    unsigned char: "%hhu", \
                    short int: "%hd", \
                    unsigned short int: "%hu", \
                    int: "%d", \
                    unsigned int: "%u", \
                    long: "%ld", \
                    unsigned long: "%lu", \
                    long long: "%lld", \
                    unsigned long long: "%llu", \
                    float: "%.6f", \
                    double: "%.6f", \
                    long double: "%ld"), \
           CONSTANT_NAME); \
    printf("\n");

int main() {
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_HIGH);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_LOW);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_MEDIUM);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_BACKGROUND);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_FAMILY);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_FOREGROUND);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_OVERLINE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_OVERLINE_NONE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_OVERLINE_SINGLE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_SIZE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_CONDENSED);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_EXPANDED);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_EXTRA_CONDENSED);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_EXTRA_EXPANDED);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_NORMAL);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_SEMI_CONDENSED);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_SEMI_EXPANDED);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_ULTRA_CONDENSED);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRETCH_ULTRA_EXPANDED);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STRIKETHROUGH);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STYLE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STYLE_ITALIC);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STYLE_NORMAL);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_STYLE_OBLIQUE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_UNDERLINE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_UNDERLINE_DOUBLE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_UNDERLINE_ERROR);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_UNDERLINE_NONE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_UNDERLINE_SINGLE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_VARIANT);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_VARIANT_ALL_PETITE_CAPS);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_VARIANT_ALL_SMALL_CAPS);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_VARIANT_PETITE_CAPS);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_VARIANT_SMALL_CAPS);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_VARIANT_TITLE_CAPS);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_VARIANT_UNICASE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_ATTRIBUTE_WEIGHT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_AUTOCOMPLETE_BOTH);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_AUTOCOMPLETE_INLINE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_AUTOCOMPLETE_LIST);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_AUTOCOMPLETE_NONE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_INVALID_FALSE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_INVALID_GRAMMAR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_INVALID_SPELLING);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_INVALID_TRUE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PLATFORM_STATE_ACTIVE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PLATFORM_STATE_FOCUSABLE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PLATFORM_STATE_FOCUSED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_AUTOCOMPLETE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_DESCRIPTION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_HAS_POPUP);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_HELP_TEXT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_KEY_SHORTCUTS);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_LABEL);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_LEVEL);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_MODAL);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_MULTI_LINE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_MULTI_SELECTABLE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_ORIENTATION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_PLACEHOLDER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_READ_ONLY);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_REQUIRED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_ROLE_DESCRIPTION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_SORT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_VALUE_MAX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_VALUE_MIN);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_VALUE_NOW);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_PROPERTY_VALUE_TEXT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_ACTIVE_DESCENDANT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_COL_COUNT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_COL_INDEX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_COL_INDEX_TEXT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_COL_SPAN);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_CONTROLLED_BY);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_CONTROLS);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_DESCRIBED_BY);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_DESCRIPTION_FOR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_DETAILS);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_DETAILS_FOR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_ERROR_MESSAGE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_ERROR_MESSAGE_FOR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_FLOW_FROM);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_FLOW_TO);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_LABELLED_BY);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_LABEL_FOR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_OWNS);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_POS_IN_SET);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_ROW_COUNT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_ROW_INDEX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_ROW_INDEX_TEXT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_ROW_SPAN);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_RELATION_SET_SIZE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_ALERT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_ALERT_DIALOG);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_APPLICATION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_ARTICLE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_BANNER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_BLOCK_QUOTE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_BUTTON);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_CAPTION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_CELL);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_CHECKBOX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_COLUMN_HEADER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_COMBO_BOX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_COMMAND);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_COMMENT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_COMPOSITE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_DIALOG);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_DOCUMENT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_FEED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_FORM);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_GENERIC);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_GRID);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_GRID_CELL);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_GROUP);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_HEADING);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_IMG);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_INPUT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_LABEL);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_LANDMARK);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_LEGEND);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_LINK);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_LIST);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_LIST_BOX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_LIST_ITEM);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_LOG);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_MAIN);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_MARQUEE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_MATH);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_MENU);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_MENU_BAR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_MENU_ITEM);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_MENU_ITEM_CHECKBOX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_MENU_ITEM_RADIO);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_METER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_NAVIGATION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_NONE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_NOTE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_OPTION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_PARAGRAPH);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_PRESENTATION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_PROGRESS_BAR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_RADIO);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_RADIO_GROUP);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_RANGE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_REGION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_ROW);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_ROW_GROUP);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_ROW_HEADER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SCROLLBAR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SEARCH);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SEARCH_BOX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SECTION);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SECTION_HEAD);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SELECT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SEPARATOR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SLIDER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SPIN_BUTTON);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_STATUS);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_STRUCTURE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_SWITCH);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TAB);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TABLE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TAB_LIST);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TAB_PANEL);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TERMINAL);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TEXT_BOX);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TIME);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TIMER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TOGGLE_BUTTON);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TOOLBAR);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TOOLTIP);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TREE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TREE_GRID);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_TREE_ITEM);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_WIDGET);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_ROLE_WINDOW);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_SORT_ASCENDING);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_SORT_DESCENDING);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_SORT_NONE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_SORT_OTHER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_BUSY);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_CHECKED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_DISABLED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_EXPANDED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_HIDDEN);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_INVALID);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_PRESSED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_SELECTED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_STATE_VISITED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TEXT_CONTENT_CHANGE_INSERT);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TEXT_CONTENT_CHANGE_REMOVE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TEXT_GRANULARITY_CHARACTER);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TEXT_GRANULARITY_LINE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TEXT_GRANULARITY_PARAGRAPH);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TEXT_GRANULARITY_SENTENCE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TEXT_GRANULARITY_WORD);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TRISTATE_FALSE);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TRISTATE_MIXED);
    PRINT_CONSTANT((gint) GTK_ACCESSIBLE_TRISTATE_TRUE);
    PRINT_CONSTANT(GTK_ACCESSIBLE_VALUE_UNDEFINED);
    PRINT_CONSTANT((gint) GTK_ALIGN_BASELINE);
    PRINT_CONSTANT((gint) GTK_ALIGN_BASELINE_CENTER);
    PRINT_CONSTANT((gint) GTK_ALIGN_BASELINE_FILL);
    PRINT_CONSTANT((gint) GTK_ALIGN_CENTER);
    PRINT_CONSTANT((gint) GTK_ALIGN_END);
    PRINT_CONSTANT((gint) GTK_ALIGN_FILL);
    PRINT_CONSTANT((gint) GTK_ALIGN_START);
    PRINT_CONSTANT((guint) GTK_APPLICATION_INHIBIT_IDLE);
    PRINT_CONSTANT((guint) GTK_APPLICATION_INHIBIT_LOGOUT);
    PRINT_CONSTANT((guint) GTK_APPLICATION_INHIBIT_SUSPEND);
    PRINT_CONSTANT((guint) GTK_APPLICATION_INHIBIT_SWITCH);
    PRINT_CONSTANT((gint) GTK_ARROW_DOWN);
    PRINT_CONSTANT((gint) GTK_ARROW_LEFT);
    PRINT_CONSTANT((gint) GTK_ARROW_NONE);
    PRINT_CONSTANT((gint) GTK_ARROW_RIGHT);
    PRINT_CONSTANT((gint) GTK_ARROW_UP);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_CONFIRM);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_CONTENT);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_CUSTOM);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_INTRO);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_PROGRESS);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_SUMMARY);
    PRINT_CONSTANT((gint) GTK_BASELINE_POSITION_BOTTOM);
    PRINT_CONSTANT((gint) GTK_BASELINE_POSITION_CENTER);
    PRINT_CONSTANT((gint) GTK_BASELINE_POSITION_TOP);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_DASHED);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_DOTTED);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_DOUBLE);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_GROOVE);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_HIDDEN);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_INSET);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_NONE);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_OUTSET);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_RIDGE);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_SOLID);
    PRINT_CONSTANT((guint) GTK_BUILDER_CLOSURE_SWAPPED);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_DUPLICATE_ID);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_ATTRIBUTE);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_FUNCTION);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_ID);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_PROPERTY);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_SIGNAL);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_TAG);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_TYPE_FUNCTION);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_VALUE);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_MISSING_ATTRIBUTE);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_MISSING_PROPERTY_VALUE);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_OBJECT_TYPE_REFUSED);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_TEMPLATE_MISMATCH);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_UNHANDLED_TAG);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_VERSION_MISMATCH);
    PRINT_CONSTANT((gint) GTK_BUTTONS_CANCEL);
    PRINT_CONSTANT((gint) GTK_BUTTONS_CLOSE);
    PRINT_CONSTANT((gint) GTK_BUTTONS_NONE);
    PRINT_CONSTANT((gint) GTK_BUTTONS_OK);
    PRINT_CONSTANT((gint) GTK_BUTTONS_OK_CANCEL);
    PRINT_CONSTANT((gint) GTK_BUTTONS_YES_NO);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_ACCEL_MODE_GTK);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_ACCEL_MODE_OTHER);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_EXPANDABLE);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_EXPANDED);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_FOCUSED);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_INSENSITIVE);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_MODE_ACTIVATABLE);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_MODE_EDITABLE);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_MODE_INERT);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_PRELIT);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_SELECTED);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_SORTED);
    PRINT_CONSTANT((gint) GTK_COLLATION_FILENAME);
    PRINT_CONSTANT((gint) GTK_COLLATION_NONE);
    PRINT_CONSTANT((gint) GTK_COLLATION_UNICODE);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_BASELINE);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_BOTTOM);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_CENTER_X);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_CENTER_Y);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_END);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_HEIGHT);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_LEFT);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_NONE);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_RIGHT);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_START);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_TOP);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_ATTRIBUTE_WIDTH);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_RELATION_EQ);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_RELATION_GE);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_RELATION_LE);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_STRENGTH_MEDIUM);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_STRENGTH_REQUIRED);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_STRENGTH_STRONG);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_STRENGTH_WEAK);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_ATTRIBUTE);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_METRIC);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_PRIORITY);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_RELATION);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_SYMBOL);
    PRINT_CONSTANT((gint) GTK_CONSTRAINT_VFL_PARSER_ERROR_INVALID_VIEW);
    PRINT_CONSTANT((gint) GTK_CONTENT_FIT_CONTAIN);
    PRINT_CONSTANT((gint) GTK_CONTENT_FIT_COVER);
    PRINT_CONSTANT((gint) GTK_CONTENT_FIT_FILL);
    PRINT_CONSTANT((gint) GTK_CONTENT_FIT_SCALE_DOWN);
    PRINT_CONSTANT((gint) GTK_CORNER_BOTTOM_LEFT);
    PRINT_CONSTANT((gint) GTK_CORNER_BOTTOM_RIGHT);
    PRINT_CONSTANT((gint) GTK_CORNER_TOP_LEFT);
    PRINT_CONSTANT((gint) GTK_CORNER_TOP_RIGHT);
    PRINT_CONSTANT((gint) GTK_CSS_PARSER_ERROR_FAILED);
    PRINT_CONSTANT((gint) GTK_CSS_PARSER_ERROR_IMPORT);
    PRINT_CONSTANT((gint) GTK_CSS_PARSER_ERROR_NAME);
    PRINT_CONSTANT((gint) GTK_CSS_PARSER_ERROR_SYNTAX);
    PRINT_CONSTANT((gint) GTK_CSS_PARSER_ERROR_UNKNOWN_VALUE);
    PRINT_CONSTANT((gint) GTK_CSS_PARSER_WARNING_DEPRECATED);
    PRINT_CONSTANT((gint) GTK_CSS_PARSER_WARNING_SYNTAX);
    PRINT_CONSTANT((gint) GTK_CSS_PARSER_WARNING_UNIMPLEMENTED);
    PRINT_CONSTANT((guint) GTK_DEBUG_A11Y);
    PRINT_CONSTANT((guint) GTK_DEBUG_ACTIONS);
    PRINT_CONSTANT((guint) GTK_DEBUG_BUILDER);
    PRINT_CONSTANT((guint) GTK_DEBUG_BUILDER_OBJECTS);
    PRINT_CONSTANT((guint) GTK_DEBUG_BUILDER_TRACE);
    PRINT_CONSTANT((guint) GTK_DEBUG_CONSTRAINTS);
    PRINT_CONSTANT((guint) GTK_DEBUG_CSS);
    PRINT_CONSTANT((guint) GTK_DEBUG_GEOMETRY);
    PRINT_CONSTANT((guint) GTK_DEBUG_ICONFALLBACK);
    PRINT_CONSTANT((guint) GTK_DEBUG_ICONTHEME);
    PRINT_CONSTANT((guint) GTK_DEBUG_INTERACTIVE);
    PRINT_CONSTANT((guint) GTK_DEBUG_INVERT_TEXT_DIR);
    PRINT_CONSTANT((guint) GTK_DEBUG_KEYBINDINGS);
    PRINT_CONSTANT((guint) GTK_DEBUG_LAYOUT);
    PRINT_CONSTANT((guint) GTK_DEBUG_MODULES);
    PRINT_CONSTANT((guint) GTK_DEBUG_NO_CSS_CACHE);
    PRINT_CONSTANT((guint) GTK_DEBUG_PRINTING);
    PRINT_CONSTANT((guint) GTK_DEBUG_SESSION);
    PRINT_CONSTANT((guint) GTK_DEBUG_SIZE_REQUEST);
    PRINT_CONSTANT((guint) GTK_DEBUG_SNAPSHOT);
    PRINT_CONSTANT((guint) GTK_DEBUG_TEXT);
    PRINT_CONSTANT((guint) GTK_DEBUG_TOUCHSCREEN);
    PRINT_CONSTANT((guint) GTK_DEBUG_TREE);
    PRINT_CONSTANT((gint) GTK_DELETE_CHARS);
    PRINT_CONSTANT((gint) GTK_DELETE_DISPLAY_LINES);
    PRINT_CONSTANT((gint) GTK_DELETE_DISPLAY_LINE_ENDS);
    PRINT_CONSTANT((gint) GTK_DELETE_PARAGRAPHS);
    PRINT_CONSTANT((gint) GTK_DELETE_PARAGRAPH_ENDS);
    PRINT_CONSTANT((gint) GTK_DELETE_WHITESPACE);
    PRINT_CONSTANT((gint) GTK_DELETE_WORDS);
    PRINT_CONSTANT((gint) GTK_DELETE_WORD_ENDS);
    PRINT_CONSTANT((guint) GTK_DIALOG_DESTROY_WITH_PARENT);
    PRINT_CONSTANT((gint) GTK_DIALOG_ERROR_CANCELLED);
    PRINT_CONSTANT((gint) GTK_DIALOG_ERROR_DISMISSED);
    PRINT_CONSTANT((gint) GTK_DIALOG_ERROR_FAILED);
    PRINT_CONSTANT((guint) GTK_DIALOG_MODAL);
    PRINT_CONSTANT((guint) GTK_DIALOG_USE_HEADER_BAR);
    PRINT_CONSTANT((gint) GTK_DIR_DOWN);
    PRINT_CONSTANT((gint) GTK_DIR_LEFT);
    PRINT_CONSTANT((gint) GTK_DIR_RIGHT);
    PRINT_CONSTANT((gint) GTK_DIR_TAB_BACKWARD);
    PRINT_CONSTANT((gint) GTK_DIR_TAB_FORWARD);
    PRINT_CONSTANT((gint) GTK_DIR_UP);
    PRINT_CONSTANT((gint) GTK_EDITABLE_NUM_PROPERTIES);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_COMPLETE_TEXT);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_CURSOR_POSITION);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_EDITABLE);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_ENABLE_UNDO);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_MAX_WIDTH_CHARS);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_SELECTION_BOUND);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_TEXT);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_WIDTH_CHARS);
    PRINT_CONSTANT((gint) GTK_EDITABLE_PROP_XALIGN);
    PRINT_CONSTANT((gint) GTK_ENTRY_ICON_PRIMARY);
    PRINT_CONSTANT((gint) GTK_ENTRY_ICON_SECONDARY);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_BOTH_AXES);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_DISCRETE);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_HORIZONTAL);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_KINETIC);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_NONE);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_PHYSICAL_DIRECTION);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_VERTICAL);
    PRINT_CONSTANT((gint) GTK_EVENT_SEQUENCE_CLAIMED);
    PRINT_CONSTANT((gint) GTK_EVENT_SEQUENCE_DENIED);
    PRINT_CONSTANT((gint) GTK_EVENT_SEQUENCE_NONE);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ACTION_OPEN);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ACTION_SAVE);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ERROR_ALREADY_EXISTS);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ERROR_BAD_FILENAME);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ERROR_INCOMPLETE_HOSTNAME);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ERROR_NONEXISTENT);
    PRINT_CONSTANT((gint) GTK_FILTER_CHANGE_DIFFERENT);
    PRINT_CONSTANT((gint) GTK_FILTER_CHANGE_DIFFERENT_REWATCH);
    PRINT_CONSTANT((gint) GTK_FILTER_CHANGE_LESS_STRICT);
    PRINT_CONSTANT((gint) GTK_FILTER_CHANGE_LESS_STRICT_REWATCH);
    PRINT_CONSTANT((gint) GTK_FILTER_CHANGE_MORE_STRICT);
    PRINT_CONSTANT((gint) GTK_FILTER_CHANGE_MORE_STRICT_REWATCH);
    PRINT_CONSTANT((gint) GTK_FILTER_MATCH_ALL);
    PRINT_CONSTANT((gint) GTK_FILTER_MATCH_NONE);
    PRINT_CONSTANT((gint) GTK_FILTER_MATCH_SOME);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_FAMILY);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_FEATURES);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_SIZE);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_STYLE);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_VARIATIONS);
    PRINT_CONSTANT((gint) GTK_FONT_LEVEL_FACE);
    PRINT_CONSTANT((gint) GTK_FONT_LEVEL_FAMILY);
    PRINT_CONSTANT((gint) GTK_FONT_LEVEL_FEATURES);
    PRINT_CONSTANT((gint) GTK_FONT_LEVEL_FONT);
    PRINT_CONSTANT((gint) GTK_FONT_RENDERING_AUTOMATIC);
    PRINT_CONSTANT((gint) GTK_FONT_RENDERING_MANUAL);
    PRINT_CONSTANT((gint) GTK_GRAPHICS_OFFLOAD_DISABLED);
    PRINT_CONSTANT((gint) GTK_GRAPHICS_OFFLOAD_ENABLED);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_FORCE_REGULAR);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_FORCE_SYMBOLIC);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_NONE);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_PRELOAD);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_INHERIT);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_LARGE);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_NORMAL);
    PRINT_CONSTANT((gint) GTK_ICON_THEME_FAILED);
    PRINT_CONSTANT((gint) GTK_ICON_THEME_NOT_FOUND);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_ABOVE);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_BELOW);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_INTO);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_LEFT);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_RIGHT);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_NO_DROP);
    PRINT_CONSTANT((gint) GTK_IMAGE_EMPTY);
    PRINT_CONSTANT((gint) GTK_IMAGE_GICON);
    PRINT_CONSTANT((gint) GTK_IMAGE_ICON_NAME);
    PRINT_CONSTANT((gint) GTK_IMAGE_PAINTABLE);
    PRINT_CONSTANT(GTK_IM_MODULE_EXTENSION_POINT_NAME);
    PRINT_CONSTANT(GTK_INPUT_ERROR);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_EMOJI);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_INHIBIT_OSK);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_LOWERCASE);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_NONE);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_NO_EMOJI);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_NO_SPELLCHECK);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_PRIVATE);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_SPELLCHECK);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_UPPERCASE_CHARS);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_UPPERCASE_SENTENCES);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_UPPERCASE_WORDS);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_VERTICAL_WRITING);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_WORD_COMPLETION);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_ALPHA);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_DIGITS);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_EMAIL);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_FREE_FORM);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_NAME);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_NUMBER);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_PASSWORD);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_PHONE);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_PIN);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_TERMINAL);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_URL);
    PRINT_CONSTANT((gint) GTK_INSCRIPTION_OVERFLOW_CLIP);
    PRINT_CONSTANT((gint) GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_END);
    PRINT_CONSTANT((gint) GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_MIDDLE);
    PRINT_CONSTANT((gint) GTK_INSCRIPTION_OVERFLOW_ELLIPSIZE_START);
    PRINT_CONSTANT((gint) GTK_INTERFACE_COLOR_SCHEME_DARK);
    PRINT_CONSTANT((gint) GTK_INTERFACE_COLOR_SCHEME_DEFAULT);
    PRINT_CONSTANT((gint) GTK_INTERFACE_COLOR_SCHEME_LIGHT);
    PRINT_CONSTANT((gint) GTK_INTERFACE_COLOR_SCHEME_UNSUPPORTED);
    PRINT_CONSTANT((gint) GTK_INTERFACE_CONTRAST_LESS);
    PRINT_CONSTANT((gint) GTK_INTERFACE_CONTRAST_MORE);
    PRINT_CONSTANT((gint) GTK_INTERFACE_CONTRAST_NO_PREFERENCE);
    PRINT_CONSTANT((gint) GTK_INTERFACE_CONTRAST_UNSUPPORTED);
    PRINT_CONSTANT(GTK_INVALID_LIST_POSITION);
    PRINT_CONSTANT((gint) GTK_JUSTIFY_CENTER);
    PRINT_CONSTANT((gint) GTK_JUSTIFY_FILL);
    PRINT_CONSTANT((gint) GTK_JUSTIFY_LEFT);
    PRINT_CONSTANT((gint) GTK_JUSTIFY_RIGHT);
    PRINT_CONSTANT((gint) GTK_LEVEL_BAR_MODE_CONTINUOUS);
    PRINT_CONSTANT((gint) GTK_LEVEL_BAR_MODE_DISCRETE);
    PRINT_CONSTANT(GTK_LEVEL_BAR_OFFSET_FULL);
    PRINT_CONSTANT(GTK_LEVEL_BAR_OFFSET_HIGH);
    PRINT_CONSTANT(GTK_LEVEL_BAR_OFFSET_LOW);
    PRINT_CONSTANT((gint) GTK_LICENSE_0BSD);
    PRINT_CONSTANT((gint) GTK_LICENSE_AGPL_3_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_AGPL_3_0_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_APACHE_2_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_ARTISTIC);
    PRINT_CONSTANT((gint) GTK_LICENSE_BSD);
    PRINT_CONSTANT((gint) GTK_LICENSE_BSD_3);
    PRINT_CONSTANT((gint) GTK_LICENSE_CUSTOM);
    PRINT_CONSTANT((gint) GTK_LICENSE_GPL_2_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_GPL_2_0_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_GPL_3_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_GPL_3_0_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_LGPL_2_1);
    PRINT_CONSTANT((gint) GTK_LICENSE_LGPL_2_1_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_LGPL_3_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_LGPL_3_0_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_MIT_X11);
    PRINT_CONSTANT((gint) GTK_LICENSE_MPL_2_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_UNKNOWN);
    PRINT_CONSTANT((gint) GTK_LIMIT_NONE);
    PRINT_CONSTANT((gint) GTK_LIMIT_SAME_NATIVE);
    PRINT_CONSTANT((guint) GTK_LIST_SCROLL_FOCUS);
    PRINT_CONSTANT((guint) GTK_LIST_SCROLL_NONE);
    PRINT_CONSTANT((guint) GTK_LIST_SCROLL_SELECT);
    PRINT_CONSTANT((gint) GTK_LIST_TAB_ALL);
    PRINT_CONSTANT((gint) GTK_LIST_TAB_CELL);
    PRINT_CONSTANT((gint) GTK_LIST_TAB_ITEM);
    PRINT_CONSTANT(GTK_MAX_COMPOSE_LEN);
    PRINT_CONSTANT(GTK_MEDIA_FILE_EXTENSION_POINT_NAME);
    PRINT_CONSTANT((gint) GTK_MESSAGE_ERROR);
    PRINT_CONSTANT((gint) GTK_MESSAGE_INFO);
    PRINT_CONSTANT((gint) GTK_MESSAGE_OTHER);
    PRINT_CONSTANT((gint) GTK_MESSAGE_QUESTION);
    PRINT_CONSTANT((gint) GTK_MESSAGE_WARNING);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_BUFFER_ENDS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_DISPLAY_LINES);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_DISPLAY_LINE_ENDS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_HORIZONTAL_PAGES);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_LOGICAL_POSITIONS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_PAGES);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_PARAGRAPHS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_PARAGRAPH_ENDS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_VISUAL_POSITIONS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_WORDS);
    PRINT_CONSTANT((gint) GTK_NATURAL_WRAP_INHERIT);
    PRINT_CONSTANT((gint) GTK_NATURAL_WRAP_NONE);
    PRINT_CONSTANT((gint) GTK_NATURAL_WRAP_WORD);
    PRINT_CONSTANT((gint) GTK_NOTEBOOK_TAB_FIRST);
    PRINT_CONSTANT((gint) GTK_NOTEBOOK_TAB_LAST);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_BOTTOM_TO_TOP_LEFT_TO_RIGHT);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_BOTTOM_TO_TOP_RIGHT_TO_LEFT);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_LEFT_TO_RIGHT_BOTTOM_TO_TOP);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_LEFT_TO_RIGHT_TOP_TO_BOTTOM);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_RIGHT_TO_LEFT_BOTTOM_TO_TOP);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_RIGHT_TO_LEFT_TOP_TO_BOTTOM);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_TOP_TO_BOTTOM_LEFT_TO_RIGHT);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_TOP_TO_BOTTOM_RIGHT_TO_LEFT);
    PRINT_CONSTANT((gint) GTK_ORDERING_EQUAL);
    PRINT_CONSTANT((gint) GTK_ORDERING_LARGER);
    PRINT_CONSTANT((gint) GTK_ORDERING_SMALLER);
    PRINT_CONSTANT((gint) GTK_ORIENTATION_HORIZONTAL);
    PRINT_CONSTANT((gint) GTK_ORIENTATION_VERTICAL);
    PRINT_CONSTANT((gint) GTK_OVERFLOW_HIDDEN);
    PRINT_CONSTANT((gint) GTK_OVERFLOW_VISIBLE);
    PRINT_CONSTANT((gint) GTK_PACK_END);
    PRINT_CONSTANT((gint) GTK_PACK_START);
    PRINT_CONSTANT((gint) GTK_PAD_ACTION_BUTTON);
    PRINT_CONSTANT((gint) GTK_PAD_ACTION_DIAL);
    PRINT_CONSTANT((gint) GTK_PAD_ACTION_RING);
    PRINT_CONSTANT((gint) GTK_PAD_ACTION_STRIP);
    PRINT_CONSTANT((gint) GTK_PAGE_ORIENTATION_LANDSCAPE);
    PRINT_CONSTANT((gint) GTK_PAGE_ORIENTATION_PORTRAIT);
    PRINT_CONSTANT((gint) GTK_PAGE_ORIENTATION_REVERSE_LANDSCAPE);
    PRINT_CONSTANT((gint) GTK_PAGE_ORIENTATION_REVERSE_PORTRAIT);
    PRINT_CONSTANT((gint) GTK_PAGE_SET_ALL);
    PRINT_CONSTANT((gint) GTK_PAGE_SET_EVEN);
    PRINT_CONSTANT((gint) GTK_PAGE_SET_ODD);
    PRINT_CONSTANT((gint) GTK_PAN_DIRECTION_DOWN);
    PRINT_CONSTANT((gint) GTK_PAN_DIRECTION_LEFT);
    PRINT_CONSTANT((gint) GTK_PAN_DIRECTION_RIGHT);
    PRINT_CONSTANT((gint) GTK_PAN_DIRECTION_UP);
    PRINT_CONSTANT(GTK_PAPER_NAME_A3);
    PRINT_CONSTANT(GTK_PAPER_NAME_A4);
    PRINT_CONSTANT(GTK_PAPER_NAME_A5);
    PRINT_CONSTANT(GTK_PAPER_NAME_B5);
    PRINT_CONSTANT(GTK_PAPER_NAME_EXECUTIVE);
    PRINT_CONSTANT(GTK_PAPER_NAME_LEGAL);
    PRINT_CONSTANT(GTK_PAPER_NAME_LETTER);
    PRINT_CONSTANT((gint) GTK_PHASE_BUBBLE);
    PRINT_CONSTANT((gint) GTK_PHASE_CAPTURE);
    PRINT_CONSTANT((gint) GTK_PHASE_NONE);
    PRINT_CONSTANT((gint) GTK_PHASE_TARGET);
    PRINT_CONSTANT((guint) GTK_PICK_DEFAULT);
    PRINT_CONSTANT((guint) GTK_PICK_INSENSITIVE);
    PRINT_CONSTANT((guint) GTK_PICK_NON_TARGETABLE);
    PRINT_CONSTANT((gint) GTK_POLICY_ALWAYS);
    PRINT_CONSTANT((gint) GTK_POLICY_AUTOMATIC);
    PRINT_CONSTANT((gint) GTK_POLICY_EXTERNAL);
    PRINT_CONSTANT((gint) GTK_POLICY_NEVER);
    PRINT_CONSTANT((guint) GTK_POPOVER_MENU_NESTED);
    PRINT_CONSTANT((guint) GTK_POPOVER_MENU_SLIDING);
    PRINT_CONSTANT((gint) GTK_POS_BOTTOM);
    PRINT_CONSTANT((gint) GTK_POS_LEFT);
    PRINT_CONSTANT((gint) GTK_POS_RIGHT);
    PRINT_CONSTANT((gint) GTK_POS_TOP);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_COLLATE);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_COPIES);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_GENERATE_PDF);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_GENERATE_PS);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_NUMBER_UP);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_NUMBER_UP_LAYOUT);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_PAGE_SET);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_PREVIEW);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_REVERSE);
    PRINT_CONSTANT((guint) GTK_PRINT_CAPABILITY_SCALE);
    PRINT_CONSTANT((gint) GTK_PRINT_DUPLEX_HORIZONTAL);
    PRINT_CONSTANT((gint) GTK_PRINT_DUPLEX_SIMPLEX);
    PRINT_CONSTANT((gint) GTK_PRINT_DUPLEX_VERTICAL);
    PRINT_CONSTANT((gint) GTK_PRINT_ERROR_GENERAL);
    PRINT_CONSTANT((gint) GTK_PRINT_ERROR_INTERNAL_ERROR);
    PRINT_CONSTANT((gint) GTK_PRINT_ERROR_INVALID_FILE);
    PRINT_CONSTANT((gint) GTK_PRINT_ERROR_NOMEM);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_ACTION_EXPORT);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_ACTION_PREVIEW);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_ACTION_PRINT);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_RESULT_APPLY);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_RESULT_CANCEL);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_RESULT_ERROR);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_RESULT_IN_PROGRESS);
    PRINT_CONSTANT((gint) GTK_PRINT_PAGES_ALL);
    PRINT_CONSTANT((gint) GTK_PRINT_PAGES_CURRENT);
    PRINT_CONSTANT((gint) GTK_PRINT_PAGES_RANGES);
    PRINT_CONSTANT((gint) GTK_PRINT_PAGES_SELECTION);
    PRINT_CONSTANT((gint) GTK_PRINT_QUALITY_DRAFT);
    PRINT_CONSTANT((gint) GTK_PRINT_QUALITY_HIGH);
    PRINT_CONSTANT((gint) GTK_PRINT_QUALITY_LOW);
    PRINT_CONSTANT((gint) GTK_PRINT_QUALITY_NORMAL);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_COLLATE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_DEFAULT_SOURCE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_DITHER);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_DUPLEX);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_FINISHINGS);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_MEDIA_TYPE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_NUMBER_UP);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_NUMBER_UP_LAYOUT);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_N_COPIES);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_ORIENTATION);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_BASENAME);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_BIN);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_DIR);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_FILE_FORMAT);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_URI);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAGE_RANGES);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAGE_SET);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAPER_FORMAT);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAPER_HEIGHT);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAPER_WIDTH);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PRINTER);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PRINTER_LPI);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PRINT_PAGES);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_QUALITY);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_RESOLUTION);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_RESOLUTION_X);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_RESOLUTION_Y);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_REVERSE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_SCALE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_USE_COLOR);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_WIN32_DRIVER_EXTRA);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_WIN32_DRIVER_VERSION);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_FINISHED);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_FINISHED_ABORTED);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_GENERATING_DATA);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_INITIAL);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_PENDING);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_PENDING_ISSUE);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_PREPARING);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_PRINTING);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_SENDING_DATA);
    PRINT_CONSTANT(GTK_PRIORITY_RESIZE);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_INVALID_ENCODING);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_INVALID_URI);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_NOT_FOUND);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_NOT_REGISTERED);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_READ);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_UNKNOWN);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_WRITE);
    PRINT_CONSTANT((gint) GTK_REDUCED_MOTION_NO_PREFERENCE);
    PRINT_CONSTANT((gint) GTK_REDUCED_MOTION_REDUCE);
    PRINT_CONSTANT((gint) GTK_RESPONSE_ACCEPT);
    PRINT_CONSTANT((gint) GTK_RESPONSE_APPLY);
    PRINT_CONSTANT((gint) GTK_RESPONSE_CANCEL);
    PRINT_CONSTANT((gint) GTK_RESPONSE_CLOSE);
    PRINT_CONSTANT((gint) GTK_RESPONSE_DELETE_EVENT);
    PRINT_CONSTANT((gint) GTK_RESPONSE_HELP);
    PRINT_CONSTANT((gint) GTK_RESPONSE_NO);
    PRINT_CONSTANT((gint) GTK_RESPONSE_NONE);
    PRINT_CONSTANT((gint) GTK_RESPONSE_OK);
    PRINT_CONSTANT((gint) GTK_RESPONSE_REJECT);
    PRINT_CONSTANT((gint) GTK_RESPONSE_YES);
    PRINT_CONSTANT((gint) GTK_RESTORE_REASON_LAUNCH);
    PRINT_CONSTANT((gint) GTK_RESTORE_REASON_PRISTINE);
    PRINT_CONSTANT((gint) GTK_RESTORE_REASON_RECOVER);
    PRINT_CONSTANT((gint) GTK_RESTORE_REASON_RESTORE);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_FADE_SLIDE_DOWN);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_FADE_SLIDE_LEFT);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_FADE_SLIDE_RIGHT);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_FADE_SLIDE_UP);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_NONE);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SWING_DOWN);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SWING_LEFT);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SWING_RIGHT);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SWING_UP);
    PRINT_CONSTANT((gint) GTK_SCROLL_END);
    PRINT_CONSTANT((gint) GTK_SCROLL_ENDS);
    PRINT_CONSTANT((gint) GTK_SCROLL_HORIZONTAL_ENDS);
    PRINT_CONSTANT((gint) GTK_SCROLL_HORIZONTAL_PAGES);
    PRINT_CONSTANT((gint) GTK_SCROLL_HORIZONTAL_STEPS);
    PRINT_CONSTANT((gint) GTK_SCROLL_JUMP);
    PRINT_CONSTANT((gint) GTK_SCROLL_MINIMUM);
    PRINT_CONSTANT((gint) GTK_SCROLL_NATURAL);
    PRINT_CONSTANT((gint) GTK_SCROLL_NONE);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGES);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_BACKWARD);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_DOWN);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_FORWARD);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_LEFT);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_RIGHT);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_UP);
    PRINT_CONSTANT((gint) GTK_SCROLL_START);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEPS);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_BACKWARD);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_DOWN);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_FORWARD);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_LEFT);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_RIGHT);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_UP);
    PRINT_CONSTANT((gint) GTK_SELECTION_BROWSE);
    PRINT_CONSTANT((gint) GTK_SELECTION_MULTIPLE);
    PRINT_CONSTANT((gint) GTK_SELECTION_NONE);
    PRINT_CONSTANT((gint) GTK_SELECTION_SINGLE);
    PRINT_CONSTANT((gint) GTK_SENSITIVITY_AUTO);
    PRINT_CONSTANT((gint) GTK_SENSITIVITY_OFF);
    PRINT_CONSTANT((gint) GTK_SENSITIVITY_ON);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_ACCELERATOR);
    PRINT_CONSTANT((guint) GTK_SHORTCUT_ACTION_EXCLUSIVE);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_PINCH);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_ROTATE_CLOCKWISE);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_ROTATE_COUNTERCLOCKWISE);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_STRETCH);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_SWIPE_LEFT);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_SWIPE_RIGHT);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_TWO_FINGER_SWIPE_LEFT);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_TWO_FINGER_SWIPE_RIGHT);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_SCOPE_GLOBAL);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_SCOPE_LOCAL);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_SCOPE_MANAGED);
    PRINT_CONSTANT((gint) GTK_SIZE_GROUP_BOTH);
    PRINT_CONSTANT((gint) GTK_SIZE_GROUP_HORIZONTAL);
    PRINT_CONSTANT((gint) GTK_SIZE_GROUP_NONE);
    PRINT_CONSTANT((gint) GTK_SIZE_GROUP_VERTICAL);
    PRINT_CONSTANT((gint) GTK_SIZE_REQUEST_CONSTANT_SIZE);
    PRINT_CONSTANT((gint) GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH);
    PRINT_CONSTANT((gint) GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT);
    PRINT_CONSTANT((gint) GTK_SORTER_CHANGE_DIFFERENT);
    PRINT_CONSTANT((gint) GTK_SORTER_CHANGE_INVERTED);
    PRINT_CONSTANT((gint) GTK_SORTER_CHANGE_LESS_STRICT);
    PRINT_CONSTANT((gint) GTK_SORTER_CHANGE_MORE_STRICT);
    PRINT_CONSTANT((gint) GTK_SORTER_ORDER_NONE);
    PRINT_CONSTANT((gint) GTK_SORTER_ORDER_PARTIAL);
    PRINT_CONSTANT((gint) GTK_SORTER_ORDER_TOTAL);
    PRINT_CONSTANT((gint) GTK_SORT_ASCENDING);
    PRINT_CONSTANT((gint) GTK_SORT_DESCENDING);
    PRINT_CONSTANT((gint) GTK_SPIN_END);
    PRINT_CONSTANT((gint) GTK_SPIN_HOME);
    PRINT_CONSTANT((gint) GTK_SPIN_PAGE_BACKWARD);
    PRINT_CONSTANT((gint) GTK_SPIN_PAGE_FORWARD);
    PRINT_CONSTANT((gint) GTK_SPIN_STEP_BACKWARD);
    PRINT_CONSTANT((gint) GTK_SPIN_STEP_FORWARD);
    PRINT_CONSTANT((gint) GTK_SPIN_USER_DEFINED);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_CROSSFADE);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_NONE);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_DOWN_UP);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_LEFT_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_RIGHT_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_UP);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_UP_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_ROTATE_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_ROTATE_LEFT_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_ROTATE_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_UP);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_UP_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_UNDER_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_UNDER_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_UNDER_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_UNDER_UP);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_ACTIVE);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_BACKDROP);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_CHECKED);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_DIR_LTR);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_DIR_RTL);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_DROP_ACTIVE);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_FOCUSED);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_FOCUS_VISIBLE);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_FOCUS_WITHIN);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_INCONSISTENT);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_INSENSITIVE);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_LINK);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_NORMAL);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_PRELIGHT);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_SELECTED);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_VISITED);
    PRINT_CONSTANT((gint) GTK_STRING_FILTER_MATCH_MODE_EXACT);
    PRINT_CONSTANT((gint) GTK_STRING_FILTER_MATCH_MODE_PREFIX);
    PRINT_CONSTANT((gint) GTK_STRING_FILTER_MATCH_MODE_SUBSTRING);
    PRINT_CONSTANT((guint) GTK_STYLE_CONTEXT_PRINT_NONE);
    PRINT_CONSTANT((guint) GTK_STYLE_CONTEXT_PRINT_RECURSE);
    PRINT_CONSTANT((guint) GTK_STYLE_CONTEXT_PRINT_SHOW_CHANGE);
    PRINT_CONSTANT((guint) GTK_STYLE_CONTEXT_PRINT_SHOW_STYLE);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_FALLBACK);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_SETTINGS);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_THEME);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_USER);
    PRINT_CONSTANT((guint) GTK_SVG_ANIMATIONS);
    PRINT_CONSTANT(GTK_SVG_DEFAULT_FEATURES);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_FAILED_RENDERING);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_FAILED_UPDATE);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_FEATURE_DISABLED);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_IGNORED_ELEMENT);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_INVALID_ATTRIBUTE);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_INVALID_ELEMENT);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_INVALID_REFERENCE);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_INVALID_SYNTAX);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_LIMITS_EXCEEDED);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_MISSING_ATTRIBUTE);
    PRINT_CONSTANT((gint) GTK_SVG_ERROR_NOT_IMPLEMENTED);
    PRINT_CONSTANT((guint) GTK_SVG_EXTENSIONS);
    PRINT_CONSTANT((guint) GTK_SVG_EXTERNAL_RESOURCES);
    PRINT_CONSTANT((guint) GTK_SVG_SYSTEM_RESOURCES);
    PRINT_CONSTANT((guint) GTK_SVG_TRADITIONAL_SYMBOLIC);
    PRINT_CONSTANT((gint) GTK_SYMBOLIC_COLOR_ACCENT);
    PRINT_CONSTANT((gint) GTK_SYMBOLIC_COLOR_ERROR);
    PRINT_CONSTANT((gint) GTK_SYMBOLIC_COLOR_FOREGROUND);
    PRINT_CONSTANT((gint) GTK_SYMBOLIC_COLOR_SUCCESS);
    PRINT_CONSTANT((gint) GTK_SYMBOLIC_COLOR_WARNING);
    PRINT_CONSTANT((gint) GTK_SYSTEM_SETTING_DISPLAY);
    PRINT_CONSTANT((gint) GTK_SYSTEM_SETTING_DPI);
    PRINT_CONSTANT((gint) GTK_SYSTEM_SETTING_FONT_CONFIG);
    PRINT_CONSTANT((gint) GTK_SYSTEM_SETTING_FONT_NAME);
    PRINT_CONSTANT((gint) GTK_SYSTEM_SETTING_ICON_THEME);
    PRINT_CONSTANT((guint) GTK_TEXT_BUFFER_NOTIFY_AFTER_DELETE);
    PRINT_CONSTANT((guint) GTK_TEXT_BUFFER_NOTIFY_AFTER_INSERT);
    PRINT_CONSTANT((guint) GTK_TEXT_BUFFER_NOTIFY_BEFORE_DELETE);
    PRINT_CONSTANT((guint) GTK_TEXT_BUFFER_NOTIFY_BEFORE_INSERT);
    PRINT_CONSTANT((gint) GTK_TEXT_DIR_LTR);
    PRINT_CONSTANT((gint) GTK_TEXT_DIR_NONE);
    PRINT_CONSTANT((gint) GTK_TEXT_DIR_RTL);
    PRINT_CONSTANT((gint) GTK_TEXT_EXTEND_SELECTION_LINE);
    PRINT_CONSTANT((gint) GTK_TEXT_EXTEND_SELECTION_WORD);
    PRINT_CONSTANT((guint) GTK_TEXT_SEARCH_CASE_INSENSITIVE);
    PRINT_CONSTANT((guint) GTK_TEXT_SEARCH_TEXT_ONLY);
    PRINT_CONSTANT((guint) GTK_TEXT_SEARCH_VISIBLE_ONLY);
    PRINT_CONSTANT((gint) GTK_TEXT_VIEW_LAYER_ABOVE_TEXT);
    PRINT_CONSTANT((gint) GTK_TEXT_VIEW_LAYER_BELOW_TEXT);
    PRINT_CONSTANT(GTK_TEXT_VIEW_PRIORITY_VALIDATE);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_BOTTOM);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_LEFT);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_RIGHT);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_TEXT);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_TOP);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_WIDGET);
    PRINT_CONSTANT((guint) GTK_TREE_MODEL_ITERS_PERSIST);
    PRINT_CONSTANT((guint) GTK_TREE_MODEL_LIST_ONLY);
    PRINT_CONSTANT(GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID);
    PRINT_CONSTANT(GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_COLUMN_AUTOSIZE);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_COLUMN_FIXED);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_COLUMN_GROW_ONLY);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_DROP_AFTER);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_DROP_BEFORE);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_DROP_INTO_OR_BEFORE);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_GRID_LINES_BOTH);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_GRID_LINES_HORIZONTAL);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_GRID_LINES_NONE);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_GRID_LINES_VERTICAL);
    PRINT_CONSTANT((gint) GTK_UNIT_INCH);
    PRINT_CONSTANT((gint) GTK_UNIT_MM);
    PRINT_CONSTANT((gint) GTK_UNIT_NONE);
    PRINT_CONSTANT((gint) GTK_UNIT_POINTS);
    PRINT_CONSTANT((gint) GTK_UPDATE_ALWAYS);
    PRINT_CONSTANT((gint) GTK_UPDATE_IF_VALID);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_BOTTOM);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_BOTTOM_END);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_BOTTOM_LEFT);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_BOTTOM_RIGHT);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_BOTTOM_START);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_CENTER);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_END);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_LEFT);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_RIGHT);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_START);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_TOP);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_TOP_END);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_TOP_LEFT);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_TOP_RIGHT);
    PRINT_CONSTANT((gint) GTK_WINDOW_GRAVITY_TOP_START);
    PRINT_CONSTANT((gint) GTK_WRAP_CHAR);
    PRINT_CONSTANT((gint) GTK_WRAP_NONE);
    PRINT_CONSTANT((gint) GTK_WRAP_WORD);
    PRINT_CONSTANT((gint) GTK_WRAP_WORD_CHAR);
    return 0;
}
